@@ -1,4 +1,4 @@
-package Sim::OPT::Interlinear;
+#package Sim::OPT::Interlinear;
 # NOTE: TO USE THE PROGRAM AS A SCRIPT, THE LINE ABOVE SHOULD BE DELETED.
 
 # INTERLINEAR
@@ -8,7 +8,7 @@ package Sim::OPT::Interlinear;
 # This is a program for filling a design space multivariate discrete dataseries
 # through a strategy entailing distance-weighting the nearest-neihbouring gradients.
 
-#use v5.14;
+use v5.14;
 use Math::Round;
 use List::Util qw( min max reduce shuffle any );
 use Statistics::Basic qw(:all);
@@ -22,13 +22,13 @@ use feature 'say';
 no strict;
 no warnings;
 
-use Sim::OPT;
-use Sim::OPT::Morph;
-use Sim::OPT::Sim;
-use Sim::OPT::Report;
-use Sim::OPT::Descend;
-use Sim::OPT::Takechance;
-use Sim::OPT::Parcoord3d;
+#use Sim::OPT;
+#use Sim::OPT::Morph;
+#use Sim::OPT::Sim;
+#use Sim::OPT::Report;
+#use Sim::OPT::Descend;
+#use Sim::OPT::Takechance;
+#use Sim::OPT::Parcoord3d;
 # NOTE: TO USE THE PROGRAM AS A SCRIPT, THE ABOVE "use Sim::OPT..." lines should be deleted or commented.
 
 our @ISA = qw( Exporter );
@@ -639,7 +639,7 @@ sub calcmaxdist_old
 }
 
 
-sub isnear_old
+sub isnear
 {
   my ( $this, $first, $last ) = @_;
   my @bits = split( "_", $this ); #say "\@bits" . dump( @bits );
@@ -692,60 +692,6 @@ sub isnear_old
 }
 
 
-sub isnear
-{
-  my ( $this, $first, $last ) = @_;
-  my $length =  length( $this );
-  my ( @bag, @limitboxp, @limitboxm );
-
-  my $ifplus = 0;
-  my $ifminus = 0;
-
-  my $p = 2;
-  while ( $p < $length )
-  {
-    my $bit = substr( $last, $p, 1 );
-    push( @lboxp, $bit );
-    my $bit = substr( $first, $p, 1 );
-    push( @lboxm, $bit );
-    $p = $p + 4;
-  }
-  #print "\@lboxp". dump( @lboxp ) . "\n";
-  #print "\@lboxm". dump( @lboxm ) . "\n";
-
-  my $p = 2;
-  my $c = 0;
-  while ( $p < $length )
-  {
-    #print "\$p $p\n";
-    #print "\$c $c\n";
-    my $bit = substr( $this, $p, 1 ); #print "\$bit $bit\n";
-    my $bitp = $bit + 1; #print "\$bitp $bitp\n";
-    my $bitm = $bit - 1; #print "\$bitm $bitm\n";
-
-    #print "\$lboxp[\$c] $lboxp[$c]\n";
-    unless ( $bitp > $lboxp[$c] )
-    {
-      my $hypp = $this;
-      ( substr( $hypp, $p, 1, $bitp ) );
-      push( @bag, $hypp );
-    }
-
-    #print "\$lboxm[\$c] $lboxm[$c]\n";
-    unless ( $bitm < $lboxm[$c] )
-    {
-      my $hypm = $this;
-      ( substr( $hypm, $p, 1, $bitm ) );
-      push( @bag,  $hypm );
-    }
-    $p = $p + 4;
-    $c++;
-  }
-  #my @neighbours = sort { $a <=> $b } @bag; #say "\@neighbours" . dump( @neighbours );
-  return( \@bag );
-}
-
-
 sub wei
 {
   my ( $arr_ref, $relaxmethod, $overweightnearest, $parconcurrencies, $instconcurrencies, $count,
@@ -781,7 +727,9 @@ sub wei
   }
 
   my ( @arra, @arrah );
-  if ( ( $limit_checkdistgrades ne "" ) and ( $limit_checkdistgrades > $checkstop ) )
+  if ( ( $limit_checkdistgrades ne "" )
+  #and ( $limit_checkdistgrades > $checkstop )
+  )
   {
     @arrah = @arr__;
     @arra = @arrah[0..$limit_checkdistgrades];
@@ -792,11 +740,15 @@ sub wei
   }
 
   my @arrb;
-  if ( ( $limit_checkdistgrades ne "" ) and ( $limit_checkdistgrades > $checkstop ) )
+  if ( ( $limit_checkdistgrades ne "" )
+  #and ( $limit_checkdistgrades > $checkstop )
+  )
   {
     @arrb = @arrah[0..$limit_checkdistpoints];
   }
-  elsif ( ( $limit_checkdistpoints ne "" ) and ( $limit_checkdistpoints > $checkstop ) )
+  elsif ( ( $limit_checkdistpoints ne "" )
+  #and ( $limit_checkdistpoints > $checkstop ) 
+  )
   {
     my @arrb_ = @arr__;
     @arrb = @arrb_[0..$limit_checkdistpoints];
@@ -1404,7 +1356,7 @@ sub wei
   }
 
   say $tee "GOING TO CREATE NEW POINTS.";
-  my ( $wand_ref, $nears_ref ) = cyclearr( \@arr__, $minreq_forinclusion, $minreq_forgrad, \%bank, \%factlevels, $nfilter, \@arrb, $first0, $last0, \%nears ); #say $tee "\%wand OUT: " . dump( %wand );
+  my ( $wand_ref, $nears_ref ) = cyclearr( \@arr__, $minreq_forinclusion, $minreq_forgrad, \%bank, \%factlevels, $nfilter, \@arrb, $first0, $last0, \%nears ); say $tee "DONE."; #say $tee "\%wand OUT: " . dump( %wand );
   my %wand = %{ $wand_ref }; #say $tee "\%wand OUT: " . dump( %wand );
   say $tee "\nDONE.";
   %nears = %{ $nears_ref }; #say $tee "RE-UPDATED \%nears: " . dump( \%nears ) . "\nDONE.";
